@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import types
 from functools import wraps
 import unittest
 import inspect
@@ -155,26 +154,21 @@ def side_effect_ify(method):
     def new_f(self, *args, **kw):
         self._current_test_method = method
         return self.side_effects(se=DotDict())
-        # new_kw = kw.copy()
-        # new_kw.update({'se': self.side_effects()})
-        # rv = method(self, *args, **new_kw)
-        # return rv
     return new_f
 
 
 class BaseTestCase(unittest.TestCase):
-    # def setUp(self):
-    #     if hasattr(self, 'side_effects'):
-    #         self._side_effects = self.side_effects()
-
     def side_effects(self, se):
         return self.invoke(se=se)
 
     def invoke(self, se):
-        if 'se' in self._current_test_method.func_code.co_varnames:
+        try:
             rv = self._current_test_method(self, se=se)
-        else:
-            rv = self._current_test_method(self)
+        except TypeError, e:
+            if "got an unexpected keyword argument 'se'" in e.message:
+                rv = self._current_test_method(self)
+            else:
+                raise
         return rv
 
     @classmethod
@@ -184,9 +178,3 @@ class BaseTestCase(unittest.TestCase):
                                 inspect.getmembers(cls)))
         for method_name, method in methods:
             setattr(cls, method_name, side_effect_ify(method))
-            # if not hasattr(method, 'side_effects_decorator_added'):
-            #     setattr(getattr(cls, method_name), 'side_effects_decorator_added', True)
-
-    # def run(self, result=None):
-    #     test_method = getattr(self, self._testMethodName)
-    #     super(BaseTestCase, self).run(result=result)
